@@ -1,17 +1,18 @@
+import os
 import unittest
 
 from platypush.event.hook import EventCondition
 from platypush.message.event.ping import PingEvent
 
-from . import BaseTest
+from . import BaseTest, conf_dir
 
 
 class TestEventParse(BaseTest):
-    def setUp(self):
-        self.condition = EventCondition.build({
-            'type': 'platypush.message.event.ping.PingEvent',
-            'message': 'This is (the)? answer: ${answer}'
-        })
+    config_file = os.path.join(conf_dir, 'test_http_config.yaml')
+    condition = EventCondition.build({
+        'type': 'platypush.message.event.ping.PingEvent',
+        'message': 'This is (the)? answer: ${answer}'
+    })
 
     def test_event_parse(self):
         message = "GARBAGE GARBAGE this is the answer: 42"
